# The MIT License (MIT)
#
# Copyright 2021 Simon Lauger
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

variable "name" {
  type        = string
  description = "Instance name"
}

variable "dns_domain" {
  type        = string
  description = "DNS domain"
}

variable "dns_zone_id" {
  description = "Zone ID"
  default     = null
}

variable "dns_internal_ip" {
  description = "Point DNS record to internal ip"
  default     = false
}

variable "dns_record_aaaa" {
  description = "Create AAAA record"
  default     = true
}

variable "instance_count" {
  type        = number
  description = "Number of instances to deploy"
  default     = 1
}

variable "server_type" {
  type        = string
  description = "Hetzner Cloud instance type"
  default     = "cx11"
}

variable "image" {
  type        = string
  description = "Hetzner Cloud system image"
  default     = "ubuntu-18.04"
}

variable "user_data" {
  description = "Cloud-Init user data to use during server creation"
  default     = null
}

variable "ssh_keys" {
  type        = list(any)
  description = "SSH key IDs or names which should be injected into the server at creation time"
  default     = []
}

variable "keep_disk" {
  type        = bool
  description = "If true, do not upgrade the disk. This allows downgrading the server type later."
  default     = true
}

variable "labels" {
  type        = map(string)
  description = "Labels that the instance is tagged with."
  default     = {}
}

variable "location" {
  type        = string
  description = "The location name to create the server in. nbg1, fsn1 or hel1"
  default     = "nbg1"
}

variable "datacenter" {
  type        = string
  description = "The location name to create the server in. nbg1, fsn1 or hel1"
  default     = "nbg1-dc3"
}

variable "backups" {
  type        = bool
  description = "Enable or disable backups"
  default     = false
}

variable "volume" {
  type        = bool
  description = "Enable or disable an additional volume"
  default     = false
}

variable "volume_size" {
  type        = number
  description = "Size of the additional data volume"
  default     = 20
}
